/*
 * Copyright (C) 2016 Couchbase, Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALING
 * IN THE SOFTWARE.
 */

package com.couchbase.client.java.error.subdoc;

import com.couchbase.client.core.annotations.InterfaceAudience;
import com.couchbase.client.core.annotations.InterfaceStability;

/**
 * Subdocument exception thrown when the delta in an arithmetic operation (eg counter) is invalid. In this
 * SDK, this is equivalent to say that the delta is zero.
 *
 * Note that the server also returns the corresponding error code when the delta value itself is too big,
 * or not a number, but since the SDK enforces deltas to be of type long, these cases shouldn't come up.
 *
 * @author Simon Baslé
 * @since 2.2
 * @see WouldOverflowException if the delta is valid but applying it to the current value would cause an overflow.
 */
@InterfaceStability.Experimental
@InterfaceAudience.Public
public class BadDeltaException extends SubDocumentException {

    public BadDeltaException(String message) {
        super(message);
    }

    public BadDeltaException() {
        super("Delta must not be zero, or is otherwise invalid");
    }
}
